# printf "\nA:\n  b: Str\n" | xargs -0I%  python -m src %

from .tokenize import tokenize
from .make_schema import make_schema
from .make_tree import make_tree
import sys
import json
from functools import reduce, partial

rcompose = lambda *arr: reduce(lambda f, g: lambda *a, **kw: f(g(*a, **kw)), reversed(arr))

main = rcompose(
    tokenize,
    make_tree,
    make_schema,
    partial(json.dumps, indent=4)
)


string = sys.stdin.read()

# string = """
# Bot:
#     ciao: Str
# """

print(main(string))

# print(reduce(lambda a, b: a + b, reversed([1, 2])))




from fastjsonschema import compile as compile_
from .tokenize import tokenize
from .make_schema import make_schema
from .make_tree import make_tree
import sys
import json
from functools import reduce, partial

rcompose = lambda *arr: reduce(lambda f, g: lambda *a, **kw: f(g(*a, **kw)), reversed(arr))

to_jsonschema = rcompose(
    tokenize,
    make_tree,
    make_schema
)


def compile(definition,):
    jsonschema = to_jsonschema(definition)
    return compile_(jsonschema)





from setuptools import setup


setup(
    name='skema',
    version=open('VERSION').read().strip(),

    description='Schema language that compiles to json schema',
    # long_description='',
    long_description_content_type='text/markdown',

    author='Tommaso De Rossi',
    author_email='daer.tommy@gmail.com',
    license='Apache Software License 2.0',

    url='https://github.com/remorses/schema',
    keywords=['schema', 'jsonschema', 'alternative', 'readable'],
    install_requires=[x for x in open('./requirements.txt').read().strip().split('\n') if x.strip()],
    package_data={'': ['*.yaml', '*.json', '*.yml']},
    include_package_data=True,
    classifiers=[
        # How mature is this project? Common values are
        # 'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Information Technology',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    packages=['skema'],
)


